@@ -1,25 +1,24 @@
 /*
-    GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 1999  Jiri Vesely <vesely@gama.fsv.cvut.cz>
-                  2001, 2013, 2014, 2016  Ales Cepek  <cepek@fsv.cvut.cz>
-                  2016  Ales Cepek <cepek@gnu.org>
+  GNU Gama -- adjustment of geodetic networks
+  Copyright (C) 1999  Jiri Vesely <vesely@gama.fsv.cvut.cz>
+                2001, 2013, 2014, 2016  Ales Cepek  <cepek@fsv.cvut.cz>
+                2016, 2018  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library.
+  This file is part of the GNU Gama C++ library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-    MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with this library; if not, write to the Free Software
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /*************************************************************
@@ -310,9 +309,9 @@ bool ApproximateCoordinates::solve_insertion()
    */
 
   // local coordinate system (cs) must be defined now
-  const Double pom_Y = 1000;
-  const Double pom_X = 5000;
-  const Double const_distance = 1000;
+  const double pom_Y = 1000;
+  const double pom_X = 5000;
+  const double const_distance = 1000;
   PointID local_cs_1, local_cs_2;
   if(first_distance != SM.end())
     {
