@@ -1,6 +1,6 @@
 /*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2006, 2012  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 2006, 2012, 2022  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
 
@@ -99,6 +99,8 @@ namespace GNU_gama
           s_error_xml_end,
           s_error_xml_description,
           s_error_xml_line_number,
+          s_linearization_iterations,
+          s_linearization_iterations_end,
           s_network_general_parameters,
           s_network_general_parameters_end,
           s_gama_local_adjustment,
@@ -160,6 +162,8 @@ namespace GNU_gama
           s_passed_end,
           s_failed,
           s_failed_end,
+          s_not_applicable,
+          s_not_applicable_end,
           s_confidence_scale,
           s_confidence_scale_end,
           s_coordinates,
@@ -287,9 +291,11 @@ namespace GNU_gama
           t_ind,
           t_left,
           t_line_number,
+          t_linearization_iterations,
           t_lower,
           t_network_general_parameters,
           t_network_processing_summary,
+          t_not_applicable,
           t_obs,
           t_observation,
           t_observations,
@@ -388,6 +394,7 @@ namespace GNU_gama
       void degrees_of_freedom(bool);
       void defect(bool);
       void sum_of_squares(bool);
+      void linearization_iterations(bool);
       void connected_network(bool);
       void disconnected_network(bool);
       void standard_deviation(bool);
@@ -400,6 +407,7 @@ namespace GNU_gama
       void upper(bool);
       void passed(bool);
       void failed(bool);
+      void not_applicable(bool);
       void confidence_scale(bool);
       void coordinates(bool);
       void fixed(bool);
